@@ -1,6 +1,10 @@
 #ifndef REGISTER_ROUTINES_H
 #define REGISTER_ROUTINES_H
 
+#include <R.h>
+#include <Rinternals.h>
+#include <R_ext/Rdynload.h>
+
 
 SEXP reco_tune(SEXP train_data_, SEXP opts_tune_, SEXP opts_other_);
 SEXP reco_train(SEXP train_data_, SEXP model_path_, SEXP opts_);
